## Source code to reproduce results in empirical application in Section 5 of the
## paper "Partial Distributional Policy Effects" by C. Rothe

## Requires the software "R" with packages foreign, Hmisc, survey, and xtable.
## Tested on a PC with Windows Vista SP2 and R v2.13.

## Requires data sets from Nicole Fortin's website:
## http://faculty.arts.ubc.ca/nfortin/DM_maleineqexample.zip

## This code takes a long time to run. For illustrative purposes, one can run it
## using only a subset of the data.

setwd("C:/") ## Change this to actual working directory
memory.limit(4090)
source("procedures.r")
 
dat.base  <- data.frame(read.dta("usmen8385_occ.dta")[,c(1:9,21:22)])
dat.treat <- data.frame(read.dta("usmen0305_occ.dta")[,c(1:9,21:22)])

## Create "part time" indicator
dat.base[,11] <- as.numeric(dat.base[,"uhrswk"] <= 39)
dat.treat[,11] <- as.numeric(dat.treat[,"uhrswk"] <= 39)
names(dat.base)[11] <- "partt"
names(dat.treat)[11] <- "partt"

## Remove individuals that report zero hours worked
dat.base <- dat.base[-which((dat.base[,"uhrswk"]==0)),]

## Create sample weights
weights.base <- dat.base[,"eweight"] * dat.base[,"uhrswk"]
weights.treat <- dat.treat[,"eweight"] * dat.treat[,"uhrswk"]

## Estimate counterfactual CDFs using parametric CDF Estimator (Logit)
## Some details
##  discrete: give covariates which should be treated as discrete (procedure will
##            calculate bounds in this case)
## bsrep:     number of bootstrap replications
## y.grid:    number of grid points for estimating CDFs
## y.approx:  counterfactual CDFs are approximated as discrete of "y.approx" 
##            support points

test <- fppe.para(formula=lwage1~(partt+nonwhite+covered+marr+educ+I(educ^2)+exper+I((exper^2)/100))^2,
        discrete=~covered, dat.base, dat.treat, weights.base, weights.treat, y.grid = 202, bs=TRUE, bsrep=200,y.approx=2000)


## Generate Figure 1
qseq <- seq(0.05,.95,by=.05)

qq <- fppe.quantile(test,round(qseq,4))

par(mfrow=c(1,2))
par(mar=c(4.3,3.8,2,.2))
par(las=1)

## Panel A
plot(qseq, qq$estimate$observed , type="l",ylim=c(-.01,.25),xlim=c(0,1),
 ylab="Wage change",xlab="Quantile",lwd=2, main="A. Observed Wage Change and Full Policy Effect")
lines(qseq, qq$estimate$full, type="l",col=1,lty=2,lwd=2)
abline(0,0)
legend(0,.25,c("Observed Wage Change","Full Policy Effect"), lty=1:2,lwd=2)

## Panel B
plot(qseq,qq$estimate$educ, type="l",ylim=c(-.07,.08),xlim=c(0,1),ylab="Wage change",xlab="Quantile",lwd=2,
main="B. Quantile FPPE")
lines(qseq, qq$estimate$educ, type="l",col=1,lty=1,lwd=2)
lines(qseq, qq$estimate$exper, type="l",col=1,lty=2,lwd=2)
xx <- c(qseq, rev(qseq))
yy <- c(qq$estimate$covered[[1]], rev(qq$estimate$covered[[2]]))
polygon(xx,yy,col="lightgrey",lty=3,lwd=2)
abline(0,0)
legend(0,.08,c("Education","Experience","Union Coverage (identified set)"), lty=1:3,lwd=2)


## Generate Table 1
qseq <- c(.1,.25,.5,.75,.9)
mu.vals <- fppe.mean(test)

fppe.qq <- fppe.quantile(test,round(qseq,4))

fppe.mean <- fppe.mean(test)

fppe.var <- fppe.var(test,mu.vals=fppe.mean(test$main))

fppe.9010 <- fppe.qc(test,qc=c(.1,.9))

fppe.9050 <- fppe.qc(test,qc=c(.5,.9))

fppe.5010 <- fppe.qc(test,qc=c(.1,.5))

fppe.gini <- fppe.gini(test, mu.vals=fppe.mean(test))


tabout <- matrix(NA,ncol=11,nrow=12)

tabout[,1] <- c(fppe.mean$estimate$observed, fppe.mean$se$observed, 
                fppe.mean$estimate$full, fppe.mean$se$full,
                fppe.mean$estimate$educ, fppe.mean$se$educ,
                fppe.mean$estimate$exper, fppe.mean$se$exper,
                fppe.mean$estimate$covered[[2]], fppe.mean$se$covered[[2]],
                fppe.mean$estimate$covered[[1]], fppe.mean$se$covered[[1]])

for (i in 1:5) {
tabout[,1+i] <- c(fppe.qq$estimate$observed[i], fppe.qq$se$observed[i], 
                fppe.qq$estimate$full[i], fppe.qq$se$full[i],
                fppe.qq$estimate$educ[i], fppe.qq$se$educ[i],
                fppe.qq$estimate$exper[i], fppe.qq$se$exper[i],
                fppe.qq$estimate$covered[[2]][i], fppe.qq$se$covered[[2]][i],
                fppe.qq$estimate$covered[[1]][i], fppe.qq$se$covered[[1]][i])
}

tabout[,7] <- c(fppe.var$estimate$observed, fppe.var$se$observed, 
                fppe.var$estimate$full, fppe.var$se$full,
                fppe.var$estimate$educ, fppe.var$se$educ,
                fppe.var$estimate$exper, fppe.var$se$exper,
                fppe.var$estimate$covered[[2]], fppe.var$se$covered[[2]],
                fppe.var$estimate$covered[[1]], fppe.var$se$covered[[1]])

tabout[,8] <- c(fppe.9010$estimate$observed, fppe.9010$se$observed, 
                fppe.9010$estimate$full, fppe.9010$se$full,
                fppe.9010$estimate$educ, fppe.9010$se$educ,
                fppe.9010$estimate$exper, fppe.9010$se$exper,
                fppe.9010$estimate$covered[[2]], fppe.9010$se$covered[[2]],
                fppe.9010$estimate$covered[[1]], fppe.9010$se$covered[[1]])

tabout[,9] <-  c(fppe.9050$estimate$observed, fppe.9050$se$observed, 
                fppe.9050$estimate$full, fppe.9050$se$full,
                fppe.9050$estimate$educ, fppe.9050$se$educ,
                fppe.9050$estimate$exper, fppe.9050$se$exper,
                fppe.9050$estimate$covered[[2]], fppe.9050$se$covered[[2]],
                fppe.9050$estimate$covered[[1]], fppe.9050$se$covered[[1]])

tabout[,10] <- c(fppe.5010$estimate$observed, fppe.5010$se$observed, 
                fppe.5010$estimate$full, fppe.5010$se$full,
                fppe.5010$estimate$educ, fppe.5010$se$educ,
                fppe.5010$estimate$exper, fppe.5010$se$exper,
                fppe.5010$estimate$covered[[2]], fppe.5010$se$covered[[2]],
                fppe.5010$estimate$covered[[1]], fppe.5010$se$covered[[1]])

tabout[,11] <-  c(fppe.gini$estimate$observed, fppe.gini$se$observed, 
                fppe.gini$estimate$full, fppe.gini$se$full,
                fppe.gini$estimate$educ, fppe.gini$se$educ,
                fppe.gini$estimate$exper, fppe.gini$se$exper,
                fppe.gini$estimate$covered[[2]], fppe.gini$se$covered[[2]],
                fppe.gini$estimate$covered[[1]], fppe.gini$se$covered[[1]])
                

tab <- matrix(0,ncol=11,nrow=14)
tab[1:4,] <- tabout[1:4,]
tab[6:9,] <- tabout[5:8,]                                                                       
tab[11:14,] <- tabout[9:12,]
rownames(tab) <- c("Total Change","1","Full Policy Effect","2","Partial Policy Effect:",
                    "Education","3","Experience","4", "Union Coverage", "$quad$ Upper bound", "5", "$quad$ Lower bound","6" )
colnames(tab) <- c("Mean","Q10","Q25","Q50","Q75","Q90","Variance","Q90-Q10","Q90-Q50","Q50-Q10","Gini")

xtable(tab[,c(1,2,4,6,8:10)],digits=5)

